vim.cmd([[
	syntax on

	highlight PcdKey	ctermfg=cyan guifg=#00ffff
	highlight PcdValue	ctermfg=red  guifg=#ff0000

	highlight HellKey	ctermfg=cyan guifg=#00ffff
	highlight HellValue	ctermfg=red  guifg=#00ffff

	set number
	colorscheme everforest
	set background=dark
	
	let g:airline_theme='base16'

	function! s:Underline(chars)
		let chars = empty(a:chars) ? '-' : a:chars
		let nr_columns = virtcol('$') - 1
		let uline = repeat(chars, (nr_columns / len(chars)) + 1)
		put =strpart(uline, 0, nr_columns)
	endfunction
	command! -nargs=? Underline call s:Underline(<q-args>)
]])
require('plugins')

require("trouble").setup {}

require'nvim-treesitter.configs'.setup {
	ensure_installed = { "c", "lua", "vim", "bash", "cpp" },
	highlight = {
		enable = true,
	},
}

require'lualine'.setup({
    options = {
        icons_enabled = true,
        theme = cozynight,
        component_separators = { left = '', right = '' },
        section_separators = { left = '', right = '' },
        disabled_filetypes = {},
        always_divide_middle = true
    },
    sections = {
        lualine_a = { 'mode' },
        lualine_b = { 'branch', 'diff',
            {
                'diagnostics',
                sources = { "nvim_diagnostic" },
                symbols = { error = ' ', warn = ' ', info = ' ', hint = ' ' }
            }
        },
        lualine_c = { 'filename' },
        lualine_x = { 'copilot' ,'encoding', 'fileformat', 'filetype' }, -- I added copilot here
        lualine_y = { 'progress' },
        lualine_z = { 'location' }
    },
    inactive_sections = {
        lualine_a = {},
        lualine_b = {},
        lualine_c = { 'filename' },
        lualine_x = { 'location' },
        lualine_y = {},
        lualine_z = {}
    },
    tabline = {},
    extensions = {}
})

vim.keymap.set("n", "<leader>xx", "<cmd>TroubleToggle<cr>", {silent = true, noremap = true})

vim.lsp.enable('ccls')

